@@ -36,35 +36,30 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '15.8.1.5-2.js';
+gTestfile = '15.8.1.7-1.js';
 
 /**
-   File Name:          15.8.1.5-2.js
-   ECMA Section:       15.8.1.5.js
+   File Name:          15.8.1.7-1.js
+   ECMA Section:       15.8.1.7.js
    Description:        All value properties of the Math object should have
    the attributes [DontEnum, DontDelete, ReadOnly]
 
-   this test checks the DontDelete attribute of Math.LOG10E
+   this test checks the ReadOnly attribute of Math.SQRT1_2
 
    Author:             christine@netscape.com
    Date:               16 september 1997
 */
 
-var SECTION = "15.8.1.5-2";
+var SECTION = "15.8.1.7-1";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Math.LOG10E";
+var TITLE   = "Math.SQRT1_2";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
 new TestCase( SECTION,
-	      "delete Math.LOG10E; Math.LOG10E",  
-	      0.4342944819032518,    
-	      eval("delete Math.LOG10E; Math.LOG10E") );
-
-new TestCase( SECTION,
-	      "delete Math.LOG10E",               
-	      false,                 
-	      eval("delete Math.LOG10E") );
+	      "Math.SQRT1_2=0; Math.SQRT1_2",
+	      0.7071067811865476,
+	      eval("Math.SQRT1_2=0; Math.SQRT1_2") );
 
 test();
